@@ -5,16 +5,16 @@
 
 // Console width and height information
 #if defined(LIBRAPID_OS_WINDOWS)
+
 #include <windows.h>
+
 #elif defined(LIBRAPID_OS_UNIX)
 #include <sys/ioctl.h>
 #include <unistd.h>
 #endif
 
-namespace librapid
-{
-	struct consoleSize
-	{
+namespace librapid {
+	struct consoleSize {
 		int64_t rows;
 		int64_t cols;
 	};
