@@ -1,18 +1,14 @@
 #include <librapid/utils/time_utils.hpp>
 
-namespace librapid
-{
-	double seconds()
-	{
+namespace librapid {
+	double seconds() {
 		return (double) std::chrono::high_resolution_clock().now().time_since_epoch().count() / 1000000000;
 	}
 
-	void sleep(double s)
-	{
+	void sleep(double s) {
 		auto start = seconds();
 
-		while (seconds() - start < s)
-		{
+		while (seconds() - start < s) {
 		}
 	}
 }
\ No newline at end of file
